@@ -300,10 +300,13 @@ class ExportExcelMixin:
                 else:
                     field_value = getattr(obj, field_name)
 
-                if get_field_type_in_py(obj, field_name) in ['int', 'float', 'bool']:
+                tp = get_field_type_in_py(obj, field_name)
+                if tp in ['int', 'float', 'bool']:
                     data.append(field_value)
                 # if get_field_type_in_py(obj, field_name) == 'bool':
                 #     data.append(field_value)
+                elif tp == 'FileField':
+                    data.append(f'{field_value}')
                 else:
                     data.append(f'{field_value}' if field_value else field_value)
 
